@@ -5,15 +5,18 @@ import "github.com/zyedidia/micro/internal/buffer"
 var InfoBar *InfoPane
 var LogBufPane *BufPane
 
+// InitGlobals initializes the log buffer and the info bar
 func InitGlobals() {
 	InfoBar = NewInfoBar()
 	buffer.LogBuf = buffer.NewBufferFromString("", "Log", buffer.BTLog)
 }
 
+// GetInfoBar returns the infobar pane
 func GetInfoBar() *InfoPane {
 	return InfoBar
 }
 
+// WriteLog writes a string to the log buffer
 func WriteLog(s string) {
 	buffer.WriteLog(s)
 	if LogBufPane != nil {
@@ -28,7 +31,10 @@ func WriteLog(s string) {
 	}
 }
 
-func OpenLogBuf(h *BufPane) {
+// OpenLogBuf opens the log buffer from the current bufpane
+// If the current bufpane is a log buffer nothing happens,
+// otherwise the log buffer is opened in a horizontal split
+func (h *BufPane) OpenLogBuf() {
 	LogBufPane = h.HSplitBuf(buffer.LogBuf)
 	LogBufPane.CursorEnd()
 
