@@ -410,11 +410,13 @@ func (w *BufWindow) displayBuffer() {
 	if len(b.Modifications) > 0 {
 		if b.Settings["syntax"].(bool) && b.SyntaxDef != nil {
 			for _, r := range b.Modifications {
+				rx := util.Clamp(r.X, 0, b.LinesNum())
+				ry := util.Clamp(r.Y, 0, b.LinesNum())
 				final := -1
-				for i := r.X; i <= r.Y; i++ {
+				for i := rx; i <= ry; i++ {
 					final = util.Max(b.Highlighter.ReHighlightStates(b, i), final)
 				}
-				b.Highlighter.HighlightMatches(b, r.X, final+1)
+				b.Highlighter.HighlightMatches(b, rx, final+1)
 			}
 		}
 
@@ -430,7 +432,7 @@ func (w *BufWindow) displayBuffer() {
 				// be another call to UpdateDiff when displayBuffer is called
 				// during the redraw.
 				if !synchronous {
-					screen.DrawChan <- true
+					screen.Redraw()
 				}
 			})
 		}
@@ -450,12 +452,14 @@ func (w *BufWindow) displayBuffer() {
 				r := c.RuneUnder(curX)
 				rl := c.RuneUnder(curX - 1)
 				if r == bp[0] || r == bp[1] || rl == bp[0] || rl == bp[1] {
-					mb, left := b.FindMatchingBrace(bp, curLoc)
-					matchingBraces = append(matchingBraces, mb)
-					if !left {
-						matchingBraces = append(matchingBraces, curLoc)
-					} else {
-						matchingBraces = append(matchingBraces, curLoc.Move(-1, b))
+					mb, left, found := b.FindMatchingBrace(bp, curLoc)
+					if found {
+						matchingBraces = append(matchingBraces, mb)
+						if !left {
+							matchingBraces = append(matchingBraces, curLoc)
+						} else {
+							matchingBraces = append(matchingBraces, curLoc.Move(-1, b))
+						}
 					}
 				}
 			}
